# SJTU Library Booking

A simple script that helps you book a seat in library.

# Get Started

1. Create a json file that contains all your accounts. Eg.
    ``` json
   {
       "<username>": "<password>"
   }
    ```
2. Run the script.
    ``` shell script
    $ sjtu-lib-booking config.json
    ```

## Built with

- [PySJTU](https://github.com/PhotonQuantum/pysjtu) - The Python iSJTU client for Humans. 

## License

This project is licensed under GNU General Public License v3.0 - see the [LICENSE.md](https://github.com/PhotonQuantum/sjtu-lib-booking/blob/master/LICENSE.md) file for details.

<p align="center">&mdash;💖&mdash;</p>
<p align="center"><i>Built with love by LightQuantum</i></p>
